@@ -1,6 +1,6 @@
-/*  $Id$
- *
- *  Copyright (c) 2006 Mike Massonnet <mmassonnet@gmail.com>
+/*
+ *  Notes - panel plugin for Xfce Desktop Environment
+ *  Copyright (c) 2006-2008  Mike Massonnet <mmassonnet@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,34 +24,13 @@
 #include <libxfce4panel/xfce-panel-plugin.h>
 #include <libxfce4panel/xfce-panel-convenience.h>
 #include <libxfcegui4/libxfcegui4.h>
+#ifdef HAVE_XFCONF
+#include <xfconf/xfconf.h>
+#endif
 #ifdef HAVE_THUNAR_VFS
 #include <thunar-vfs/thunar-vfs.h>
 #endif
 
-typedef struct _NotesPlugin     NotesPlugin;
-struct _NotesPlugin
-{
-  XfcePanelPlugin      *panel_plugin;
-  GSList               *windows;
-  gchar                *config_file;
-  gchar                *notes_path;
-  guint                 timeout;
-
-  GtkWidget            *btn_panel;
-  GtkWidget            *icon_panel;
-  GtkWidget            *menu;
-  GtkWidget            *icon;
-  GtkWidget            *icon_rev;
-
-  GtkTooltips          *tooltips;
-
-#ifdef HAVE_THUNAR_VFS
-  ThunarVfsMonitor     *monitor;
-  ThunarVfsPath        *thunar_vfs_path;
-  ThunarVfsMonitorHandle *monitor_handle;
-#endif
-};
-
 typedef enum
 {
   LAST_STATE,
@@ -59,7 +38,39 @@ typedef enum
   NEVER,
 } ShowOnStartup;
 
+typedef struct _NotesPlugin     NotesPlugin;
 typedef struct _NotesWindow     NotesWindow;
+typedef struct _NotesNote       NotesNote;
+
+struct _NotesPlugin
+{
+  XfcePanelPlugin      *panel_plugin;
+  GSList               *windows;
+  gchar                *config_file;
+  gchar                *notes_path;
+  guint                 timeout;
+
+  GtkWidget            *box_panel;
+  GtkWidget            *btn_panel;
+  GtkWidget            *icon_panel;
+  GtkWidget            *btn_arrow;
+  GtkWidget            *menu;
+  GtkWidget            *icon;
+  GtkWidget            *icon_rev;
+
+  GtkTooltips          *tooltips;
+
+#ifdef HAVE_XFCONF
+  XfconfChannel        *channel_panel_plugin;
+  XfconfChannel        *channel_new_window;
+#endif
+#ifdef HAVE_THUNAR_VFS
+  ThunarVfsMonitor     *monitor;
+  ThunarVfsPath        *thunar_vfs_path;
+  ThunarVfsMonitorHandle *monitor_handle;
+#endif
+};
+
 struct _NotesWindow
 {
   NotesPlugin          *notes_plugin;
@@ -100,7 +111,6 @@ struct _NotesWindow
 #endif
 };
 
-typedef struct _NotesNote       NotesNote;
 struct _NotesNote
 {
   NotesWindow          *notes_window;
@@ -117,11 +127,6 @@ struct _NotesNote
 #endif
 };
 
-typedef struct _NotesOptions    NotesOptions;
-struct _NotesOptions
-{
-};
-
 
 
 const gchar *           notes_window_read_name          (NotesPlugin *notes_plugin);
