@@ -1,8 +1,7 @@
-/* $Id$
- *
+/*
  *  Notes - panel plugin for Xfce Desktop Environment
- *  Copyright (C) 2003  Jakob Henriksson <b0kaj+dev@lysator.liu.se>
- *  Copyright (C) 2006  Mike Massonnet <mmassonnet@gmail.com>
+ *  Copyright (C) 2003       Jakob Henriksson <b0kaj+dev@lysator.liu.se>
+ *  Copyright (C) 2006-2008  Mike Massonnet <mmassonnet@xfce.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,10 +23,15 @@
 #include <config.h>
 #endif
 
+#include "defines.h"
 #include "notes.h"
+#ifdef HAVE_XFCONF
+#include "notes-properties-dialog.h"
+#endif
 #include "xfce4-popup-notes.h"
 
 #define PLUGIN_NAME "xfce4-notes-plugin"
+#define PLUGIN_WEBSITE "http://goodies.xfce.org/projects/panel-plugins/xfce4-notes-plugin"
 
 
 
@@ -35,8 +39,13 @@ static void             notes_plugin_register           (XfcePanelPlugin *panel_
 
 static NotesPlugin     *notes_plugin_new                (XfcePanelPlugin *panel_plugin);
 
+#ifdef HAVE_XFCONF
+static void             notes_plugin_configure          (NotesPlugin *notes_plugin);
+#endif
 static gboolean         notes_plugin_set_size           (NotesPlugin *notes_plugin, 
                                                          int size);
+static void             notes_plugin_set_orientation    (NotesPlugin *notes_plugin, 
+                                                         GtkOrientation orientation);
 static void             notes_plugin_load_data          (NotesPlugin *notes_plugin);
 
 static inline void      notes_plugin_save_data          (NotesPlugin *notes_plugin);
@@ -46,7 +55,14 @@ static void             notes_plugin_save_data_all      (NotesPlugin *notes_plug
 static void             notes_plugin_free               (NotesPlugin *notes_plugin);
 
 static void             notes_plugin_destroy_timeout    (NotesPlugin *notes_plugin);
+#ifdef HAVE_XFCONF
+static void             notes_plugin_monitor_xfconf     (NotesPlugin *notes_plugin);
 
+static void             notes_plugin_xfconf_property_changed
+                                                        (NotesPlugin *notes_plugin,
+                                                         gchar *property,
+                                                         GValue *value);
+#endif
 #ifdef HAVE_THUNAR_VFS
 static NotesWindow     *notes_plugin_get_window_by_name (NotesPlugin *notes_plugin,
                                                          const gchar *name);
@@ -57,6 +73,8 @@ static void             notes_plugin_fs_event           (ThunarVfsMonitor *monit
                                                          ThunarVfsPath *event_path,
                                                          NotesPlugin *notes_plugin);
 #endif
+static gboolean         notes_plugin_arrow_pressed      (NotesPlugin *notes_plugin,
+                                                         GdkEventButton *event);
 static gboolean         notes_plugin_button_pressed     (NotesPlugin *notes_plugin,
                                                          GdkEventButton *event);
 static gboolean         notes_plugin_button_released    (NotesPlugin *notes_plugin,
@@ -92,6 +110,16 @@ notes_plugin_register (XfcePanelPlugin *panel_plugin)
 
   NotesPlugin *notes_plugin = notes_plugin_new (panel_plugin);
   g_return_if_fail (G_LIKELY (notes_plugin != NULL));
+#ifdef HAVE_XFCONF
+  notes_plugin_monitor_xfconf (notes_plugin);
+#endif
+
+  gtk_widget_show_all (GTK_WIDGET (panel_plugin));
+#ifdef HAVE_XFCONF
+  if (xfconf_channel_get_bool (notes_plugin->channel_panel_plugin, "/hide_arrow_button", FALSE))
+    gtk_widget_hide (notes_plugin->btn_arrow);
+#endif
+
   notes_plugin_load_data (notes_plugin);
 }
 
@@ -115,20 +143,36 @@ notes_plugin_new (XfcePanelPlugin *panel_plugin)
   DBG ("\nLook up file: %s\nNotes path: %s", notes_plugin->config_file,
                                            notes_plugin->notes_path);
 
+#ifdef HAVE_XFCONF
+  xfconf_init (NULL);
+#endif
+
   notes_plugin->windows = NULL;
+  notes_plugin->box_panel = GTK_WIDGET (xfce_hvbox_new (GTK_ORIENTATION_HORIZONTAL, FALSE, 0));
   notes_plugin->btn_panel = xfce_create_panel_toggle_button ();
   notes_plugin->icon_panel = gtk_image_new ();
-  notes_plugin->tooltips = gtk_tooltips_new ();
+  notes_plugin->btn_arrow = GTK_WIDGET (xfce_arrow_button_new (GTK_ARROW_UP));
+  gtk_button_set_relief (GTK_BUTTON (notes_plugin->btn_arrow), GTK_RELIEF_NONE);
 
-  gtk_container_add (GTK_CONTAINER (notes_plugin->btn_panel),
-                     notes_plugin->icon_panel);
-  gtk_container_add (GTK_CONTAINER (panel_plugin),
-                     notes_plugin->btn_panel);
+  gtk_container_add (GTK_CONTAINER (notes_plugin->btn_panel), notes_plugin->icon_panel);
+  gtk_container_add (GTK_CONTAINER (notes_plugin->box_panel), notes_plugin->btn_panel);
+  gtk_container_add (GTK_CONTAINER (notes_plugin->box_panel), notes_plugin->btn_arrow);
+  gtk_container_add (GTK_CONTAINER (panel_plugin), notes_plugin->box_panel);
 
+#ifdef HAVE_XFCONF
+  g_signal_connect_swapped (panel_plugin,
+                            "configure-plugin",
+                            G_CALLBACK (notes_plugin_configure),
+                            notes_plugin);
+#endif
   g_signal_connect_swapped (panel_plugin,
                             "size-changed",
                             G_CALLBACK (notes_plugin_set_size),
                             notes_plugin);
+  g_signal_connect_swapped (panel_plugin,
+                            "orientation-changed",
+                            G_CALLBACK (notes_plugin_set_orientation),
+                            notes_plugin);
   g_signal_connect_swapped (panel_plugin,
                             "save",
                             G_CALLBACK (notes_plugin_save_data),
@@ -137,6 +181,10 @@ notes_plugin_new (XfcePanelPlugin *panel_plugin)
                             "free-data",
                             G_CALLBACK (notes_plugin_free),
                             notes_plugin);
+  g_signal_connect_swapped (notes_plugin->btn_arrow,
+                            "button-press-event",
+                            G_CALLBACK (notes_plugin_arrow_pressed),
+                            notes_plugin);
   g_signal_connect_swapped (notes_plugin->btn_panel,
                             "button-press-event",
                             G_CALLBACK (notes_plugin_button_pressed),
@@ -161,13 +209,40 @@ notes_plugin_new (XfcePanelPlugin *panel_plugin)
     }
 #endif
 
-  xfce_panel_plugin_add_action_widget (panel_plugin, notes_plugin->btn_panel);
   notes_plugin_set_selection (notes_plugin);
-  gtk_widget_show_all (notes_plugin->btn_panel);
+#ifdef HAVE_XFCONF
+  xfce_panel_plugin_menu_show_configure (panel_plugin);
+#endif
+  xfce_panel_plugin_add_action_widget (panel_plugin, notes_plugin->btn_panel);
+  xfce_panel_plugin_add_action_widget (panel_plugin, notes_plugin->btn_arrow);
 
   return notes_plugin;
 }
 
+#ifdef HAVE_XFCONF
+static void
+notes_plugin_configure (NotesPlugin *notes_plugin)
+{
+  GtkWidget *dialog = prop_dialog_new (notes_plugin);
+  g_return_if_fail (G_LIKELY (GTK_IS_WIDGET (dialog)));
+
+  xfce_panel_plugin_block_menu (notes_plugin->panel_plugin);
+
+  gint result = gtk_dialog_run (GTK_DIALOG (dialog));
+  if (result == GTK_RESPONSE_HELP)
+    {
+      result = g_spawn_command_line_async ("exo-open " PLUGIN_WEBSITE, NULL);
+      if (G_UNLIKELY (result == FALSE))
+        g_warning (_("Unable to open the following url: %s"), PLUGIN_WEBSITE);
+    }
+
+  if (GTK_IS_WIDGET (dialog))
+    gtk_widget_destroy (dialog);
+
+  xfce_panel_plugin_unblock_menu (notes_plugin->panel_plugin);
+}
+#endif
+
 static gboolean
 notes_plugin_set_size (NotesPlugin *notes_plugin,
                        int size)
@@ -175,8 +250,8 @@ notes_plugin_set_size (NotesPlugin *notes_plugin,
   DBG ("Set size to %d", size);
 
   gtk_widget_set_size_request (notes_plugin->btn_panel, size, size);
-  size = size - 2 - (2 * MAX (notes_plugin->btn_panel->style->xthickness,
-                              notes_plugin->btn_panel->style->ythickness));
+  size -= 2 + 2 * MAX (notes_plugin->btn_panel->style->xthickness,
+                       notes_plugin->btn_panel->style->ythickness);
   GdkPixbuf *pixbuf = xfce_themed_icon_load ("xfce4-notes-plugin", size);
   gtk_image_set_from_pixbuf (GTK_IMAGE (notes_plugin->icon_panel), pixbuf);
   g_object_unref (G_OBJECT (pixbuf));
@@ -184,6 +259,22 @@ notes_plugin_set_size (NotesPlugin *notes_plugin,
   return TRUE;
 }
 
+static void
+notes_plugin_set_orientation (NotesPlugin *notes_plugin,
+                              GtkOrientation orientation)
+{
+  xfce_hvbox_set_orientation (notes_plugin->box_panel, orientation);
+  XfceScreenPosition position = xfce_panel_plugin_get_screen_position (notes_plugin->panel_plugin);
+  if (xfce_screen_position_is_top (position))
+    xfce_arrow_button_set_arrow_type (notes_plugin->btn_arrow, GTK_ARROW_DOWN);
+  else if (xfce_screen_position_is_left (position))
+    xfce_arrow_button_set_arrow_type (notes_plugin->btn_arrow, GTK_ARROW_RIGHT);
+  else if (xfce_screen_position_is_right (position))
+    xfce_arrow_button_set_arrow_type (notes_plugin->btn_arrow, GTK_ARROW_LEFT);
+  else /*if (xfce_screen_position_is_bottom (position))*/
+    xfce_arrow_button_set_arrow_type (notes_plugin->btn_arrow, GTK_ARROW_UP);
+}
+
 static void
 notes_plugin_load_data (NotesPlugin *notes_plugin)
 {
@@ -226,6 +317,9 @@ static void
 notes_plugin_free (NotesPlugin *notes_plugin)
 {
   notes_plugin_save_data_all (notes_plugin);
+#ifdef HAVE_XFCONF
+  xfconf_shutdown ();
+#endif
 #ifdef HAVE_THUNAR_VFS
   /* TODO move code out from notes_window_destroy and add notes_window_free
    * which would only free memory and not corrupt notes or configuration data
@@ -251,6 +345,43 @@ notes_plugin_destroy_timeout (NotesPlugin *notes_plugin)
   notes_plugin->timeout = 0;
 }
 
+#ifdef HAVE_XFCONF
+static void
+notes_plugin_monitor_xfconf (NotesPlugin *notes_plugin)
+{
+  notes_plugin->channel_new_window = xfconf_channel_new (XFCONF_CHANNEL_NEW_WINDOW);
+  notes_plugin->channel_panel_plugin = xfconf_channel_new (XFCONF_CHANNEL_PANEL_PLUGIN);
+  g_signal_connect_swapped (notes_plugin->channel_panel_plugin, "property-changed",
+                            G_CALLBACK (notes_plugin_xfconf_property_changed), notes_plugin);
+}
+
+static void
+notes_plugin_xfconf_property_changed (NotesPlugin *notes_plugin,
+                                      gchar *property,
+                                      GValue *value)
+{
+  /* Refresh both elements
+   * TODO find out how to guess efficiently the property name */
+  gboolean v = g_value_get_boolean (value);
+  if (!g_ascii_strcasecmp (property, "/hide_windows_from_taskbar"))
+    {
+      GSList *l;
+      for (l = notes_plugin->windows; l != NULL; l = l->next)
+        {
+          NotesWindow *notes_window = l->data;
+          gtk_window_set_skip_taskbar_hint (GTK_WINDOW (notes_window->window), v);
+        }
+    }
+  else if (!g_ascii_strcasecmp (property, "/hide_arrow_button"))
+    {
+      if (v)
+        gtk_widget_hide (notes_plugin->btn_arrow);
+      else
+        gtk_widget_show (notes_plugin->btn_arrow);
+    }
+}
+#endif
+
 #ifdef HAVE_THUNAR_VFS
 static NotesWindow *
 notes_plugin_get_window_by_name (NotesPlugin *notes_plugin,
@@ -328,6 +459,19 @@ notes_plugin_fs_event (ThunarVfsMonitor *monitor,
 }
 #endif
 
+static gboolean
+notes_plugin_arrow_pressed (NotesPlugin *notes_plugin,
+                            GdkEventButton *event)
+{
+  if (G_LIKELY (event->button != 1 || event->state & GDK_CONTROL_MASK))
+    return FALSE;
+
+  notes_plugin_menu_popup (notes_plugin);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (notes_plugin->btn_arrow), TRUE);
+
+  return TRUE;
+}
+
 static gboolean
 notes_plugin_button_pressed (NotesPlugin *notes_plugin,
                              GdkEventButton *event)
@@ -406,8 +550,7 @@ notes_plugin_menu_new (NotesPlugin *notes_plugin)
     {
       TRACE ("notes_window (%d): %p", (i-1), notes_window);
       GtkWidget *mi_foo = gtk_image_menu_item_new_with_label (notes_window->name);
-      GtkWidget *icon = gtk_image_new_from_icon_name ("xfce4-notes-plugin",
-                                                      GTK_ICON_SIZE_MENU);
+      GtkWidget *icon = gtk_image_new_from_icon_name ("xfce4-notes-plugin", GTK_ICON_SIZE_MENU);
       gtk_widget_set_sensitive (icon, GTK_WIDGET_VISIBLE (notes_window->window));
 
       gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (mi_foo), icon);
@@ -512,6 +655,7 @@ notes_plugin_menu_destroy (NotesPlugin *notes_plugin)
   if (G_LIKELY (GTK_IS_MENU (notes_plugin->menu)))
     gtk_menu_detach (GTK_MENU (notes_plugin->menu));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (notes_plugin->btn_panel), FALSE);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (notes_plugin->btn_arrow), FALSE);
 }
 
 
